#
# spec file for package openscad
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openscad
Version:        2019.05
Release:        lp152.2.3.1
Summary:        Programmers Solid 3D CAD Modeller
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/CAD
Url:            https://www.openscad.org/
Source:         https://files.openscad.org/%{name}-%{version}.src.tar.gz
Patch1:         openscad-fix-stl-import.patch
BuildRequires:  bison
BuildRequires:  double-conversion-devel
BuildRequires:  eigen3-devel
BuildRequires:  flex
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  harfbuzz-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libcgal-devel
BuildRequires:  libqscintilla-qt5-devel
BuildRequires:  libspnav-devel
BuildRequires:  memory-constraints
BuildRequires:  opencsg-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)

%description
OpenSCAD is a software for creating solid 3D CAD objects. It does not
focus on the artistic aspects of 3D modelling and does not target the
creation of, say, computer-animated movies, but instead on the CAD
aspects, e.g. modelling of machine parts.

%prep
%setup -q -n %{name}-%{version}

%patch1 -p1

%build
qmake-qt5 PREFIX=%{_prefix} QMAKE_CXXFLAGS="%{optflags}" CONFIG+=qopenglwidget
%limit_build -m 2200
make %{?_smp_mflags}

%install
make INSTALL_ROOT=%{buildroot} install
install -D -m 0644 doc/openscad.1 %{buildroot}%{_mandir}/man1/openscad.1
# remove bundled liberation fonts
rm -rf %{buildroot}%{_datadir}/openscad/fonts
%find_lang %{name}

%files -f %{name}.lang
%doc README.md doc/*.pdf
%license COPYING
%{_bindir}/openscad
%{_datadir}/openscad/
%{_datadir}/applications/openscad.desktop
%{_datadir}/pixmaps/openscad.png
%{_mandir}/man1/*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.openscad.OpenSCAD.appdata.xml
%{_datadir}/mime/packages/openscad.xml

%changelog
* Sat May 15 2021 Samu Voutilainen <smar@smar.fi>
- Add patch openscad-fix-stl-import.patch to fix CVE-2020-28600.
* Sun Mar 22 2020 Christophe Giboudeaux <christophe@krop.fr>
- Explicitly require libboost_thread-devel for building openscad.
* Mon Jun 24 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2019.05 release
  + Language Features:
  * New modules
    assert() - stop script evaluation on failed constraints
    let() - scoped assignment
  * New functions
    ord() - convert from character to Unicode code point
    echo()
    assert() - stop script evaluation on failed constraints
    Type testing functions: is_undef(), is_list(), is_num(), is_bool(), is_string()
  * New special variable: $preview variable which is set to true in preview mode
  * List comprehension updates
    Added if/else condition
    Added each keyword
    Added C-style for loop
    Now allows looping over characters of a string
  * rotate_extrude(): Added angle parameter to
  * import() now supports SVG, 3MF and AMF
  * color() now supports hex color codes
  * Removed glide() and subdiv() which were never implemented
  + Program Features:
  * Customizer: Allow parametrizing design parameters with GUI customization
  * Support for using 3D-Mouse / Joystick / Gamepad input devices for controlling the 3D view
  * 3D Printing support: Purchase from a print service partner or print to Octoprint
  * New export file formats: SVG, 3MF, AMF
  * Quick-edit and preview of values using Alt-Arrows (Shift-Alt-Arrows on macOS)
  * Added --view cmd-line parameter
  * Play sound notification on render complete
  * Line numbers and filenames are now shown for many errors and warnings
  * Hardwarning preference: Stop on first warning
  * Hardwarning and assert now shows a stack trace
  * New warnings
    Module call parameterns don't match module declaration
    Argument value of of range
    Duplicate passed argument
    Children passed to module not accepting children
    Reference to inknown $special_variables
    Duplicate assigment
  * New translations: Ukrainian, Polish
- Updated BuildRequires:
  - Drop glew-devel and some boost headers
  - Add libspnav for 3D mouse, Qt5Multimedia for notifications
- Cleanup spec file, remove conditionals for Fedora (still targeting EOLed Qt4)
- Drop upstream patches:
  openscad-git4fa5f0340a.patch
  openscad-git_c68684f9520d.patch
* Wed Mar 20 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Cleanup BuildRequires, sort, remove duplicates
- Fix Url:, openscad.org redirects to www.openscad.org
- Add openscad-git_c68684f9520d.patch, fix build with Boost 1.69
- Use %%license, remove %%defattr
* Fri Dec 15 2017 plinnell@opensuse.org
- Fix the BuildRequires to fix build on Factory/TW
* Tue Jun 13 2017 idonmez@suse.com
- Change license to GPL-3.0+, see
  https://github.com/openscad/openscad/issues/2059
* Thu Apr 27 2017 jengelh@inai.de
- Remove useless %%clean section
- Trim description
* Sun Jan 15 2017 herbert@graeber-clan.de
- Add patch openscad-git4fa5f0340a.patch from upstream, to fix
  build with newer Qt5 and gcc versions
* Thu Dec 22 2016 herbert@graeber-clan.de
- Switch to Qt5
* Thu Nov 19 2015 prusnak@opensuse.org
- updated to 2015.03-2
* Tue Apr 21 2015 prusnak@opensuse.org
- updated to 2015.03-1
* Wed Mar 11 2015 prusnak@opensuse.org
- updated to 2015.03
* Mon Mar 10 2014 prusnak@opensuse.org
- updated to 2014.03
* Wed Jun 19 2013 prusnak@opensuse.org
- updated to 2013.06
* Sat Jan 19 2013 prusnak@opensuse.org
- updated to 2013.01
* Fri Nov 23 2012 prusnak@opensuse.org
- fix build (glu.patch)
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 2011.12
* Wed Sep  7 2011 prusnak@opensuse.org
- updated to 2011.06
* Fri May 13 2011 prusnak@opensuse.org
- updated to 2011.04
* Wed Oct 13 2010 prusnak@opensuse.org
- created package (2010.05)
